@@ -46,7 +46,7 @@ def main(raw_args=None):
     resume_queue_commandParser.add_argument("n", nargs="?", type=int, default=1, help="Track index in the current queue.")
 
     print_queue_commandParser   = mainSubCommandParser.add_parser("queue", aliases="q", help="Print the current queue.")
-    print_queue_commandParser.add_argument("i", nargs="?", type=int, default=0, help="Track index to start printing the queue from.")
+    print_queue_commandParser.add_argument("i", nargs="?", type=int, default=1, help="Track index to start printing the queue from.")
     print_queue_commandParser.add_argument("n", nargs="?", type=int, default=0, help="Number of tracks to print from the queue. Defaults to 0, which means all remaining.")
     
     args = parser.parse_args(raw_args)
@@ -70,7 +70,7 @@ def main(raw_args=None):
             client.safe_set_volume(client.volume + (int(args.action) * n), args.force)
         elif args.n:
             client.safe_set_volume(int(args.n), args.force)
-        print(client.volume)
+        return client.volume
     elif args.sub_command == "p":
         if client.get_current_transport_info()['current_transport_state'] in ["STOPPED", "PAUSED_PLAYBACK"]:
             client.play()
@@ -84,6 +84,7 @@ def main(raw_args=None):
         client.stop()
     elif args.sub_command in ["stop_after", "sa"]:
         client.stop_after(args.n)
+        print(client.get_current_status())
     elif args.sub_command in ["line_in", "li"]:
         client.switch_to_line_in(list(client.all_zones)[args.n])
         client.play()
