@@ -4,15 +4,18 @@ import time
 import sys
 
 class SonosExtras(SoCo):
+    def isPlaying(self) -> bool:
+        return self.get_current_transport_info()["current_transport_state"] == "PLAYING"
+
     def stop_after(self, songs):
-        if self.get_current_transport_info()["current_transport_state"] == "PLAYING":
+        if self.isPlaying():
             while songs >= 1:
                 if songs > 1:
                     print("\rStopping afer " + songs.__str__() + " songs...", end = '         \r\n', flush=True)
                 else:
                     print("\rStopping afer current song ...", end = '         \r\n', flush=True)
                 time.sleep(3)
-                if not self.WaitPollCurrentTrackTillEnd(early=1):
+                if self.WaitPollCurrentTrackTillEnd(early=1) == False:
                     return 1
                 songs -= 1
             print()
@@ -33,6 +36,9 @@ class SonosExtras(SoCo):
                 # resync the remaining time every 10 seconds
                 if recheck_counter == 10:
                     recheck_counter = 0
+                    if self.isPlaying() == False:
+                        print("\nPlayback has stopped before reaching the end-target!")
+                        return False
                     remainingSeconds = self._curr_track_remaining_secs() - early
             except KeyboardInterrupt:
                 if not quiet:
@@ -54,22 +60,23 @@ class SonosExtrasCliHelper(SonosExtras):
         current_volume = self.volume
         user_response = "No"
         if requested_volume - current_volume > self.volume_increase_confirmation_threshold and not forced:
-            print("Are you sure you want to set volume to " + requested_volume.__str__() + "?")
+            print("Are you sure you want to set volume from {current_volume} to {requested_volume}?")
             user_response = input()
             user_response = user_response.upper()
         if forced == True or user_response == "Y" or user_response == "YES" or not requested_volume - current_volume > self.volume_increase_confirmation_threshold:
             self.volume = requested_volume
 
-    def print_queue(self, starting_index = 0, number_of_tracks = 0):
+    def print_queue(self, starting_index = 1, number_of_tracks = 0):
         result = []
         count = starting_index
+        array_starting_index = starting_index - 1
 
         batches = max(100, number_of_tracks)
-        queue = self.get_queue(starting_index, batches)
+        queue = self.get_queue(array_starting_index, batches)
 
         if number_of_tracks == 0:
             return_rest = True
-            tracks_to_return = queue.total_matches - starting_index
+            tracks_to_return = queue.total_matches - ( starting_index - 1 )
         else:
             return_rest = False
             tracks_to_return = number_of_tracks
@@ -106,7 +113,7 @@ class SonosExtrasCliHelper(SonosExtras):
                     print("Unexpected error:", sys.exc_info()[0])
                 if tracks_to_return == returned_matches:
                     break
-            queue = self.get_queue(returned_matches + starting_index)
+            queue = self.get_queue(returned_matches + array_starting_index)
         return result
 
     def get_current_status(self):
